==> pyleoclim-0.7.2.tar.gz: pyleoclim-0.7.2/pyleoclim/tests/test_ui_Scalogram.py <==
''' Tests for pyleoclim.core.ui.Scalogram

Naming rules:
1. class: Test{filename}{Class}{method} with appropriate camel case
2. function: test_{method}_t{test_id}

Notes on how to test:
0. Make sure [pytest](https://docs.pytest.org) has been installed: `pip install pytest`
1. execute `pytest {directory_path}` in terminal to perform all tests in all testing files inside the specified directory
2. execute `pytest {file_path}` in terminal to perform all tests in the specified file
3. execute `pytest {file_path}::{TestClass}::{test_method}` in terminal to perform a specific test class/method inside the specified file
4. after `pip install pytest-xdist`, one may execute "pytest -n 4" to test in parallel with number of workers specified by `-n`
5. for more details, see https://docs.pytest.org/en/stable/usage.html
'''
import numpy as np
import pandas as pd

from numpy.testing import assert_array_equal
from pandas.testing import assert_frame_equal

import pytest

import pyleoclim as pyleo
from pyleoclim.utils.tsmodel import (
    ar1_sim,
    colored_noise,
)

# a collection of useful functions

def gen_normal(loc=0, scale=1, nt=100):
    ''' Generate random data with a Gaussian distribution
    '''
    t = np.arange(nt)
    v = np.random.normal(loc=loc, scale=scale, size=nt)
    return t, v

def gen_colored_noise(alpha=1, nt=100, f0=None, m=None, seed=None):
    ''' Generate colored noise
    '''
    t = np.arange(nt)
    v = colored_noise(alpha=alpha, t=t, f0=f0, m=m, seed=seed)
    return t, v


# Tests below
class TestUiScalogramSignifTest:
    ''' Tests for Scalogram.signif_test()
    '''

    def test_signif_test_t0(self):
        ''' Test scalogram.signif_test() with default parameters
        '''
        alpha = 1
        t, v = gen_colored_noise(nt=100, alpha=alpha)
        ts = pyleo.Series(time=t, value=v)
        scal = ts.wavelet()
        scal_signif = scal.signif_test(number=1)

==> pyleoclim-0.7.4.tar.gz: pyleoclim-0.7.4/pyleoclim/tests/test_ui_Scalogram.py <==
''' Tests for pyleoclim.core.ui.Scalogram

Naming rules:
1. class: Test{filename}{Class}{method} with appropriate camel case
2. function: test_{method}_t{test_id}

Notes on how to test:
0. Make sure [pytest](https://docs.pytest.org) has been installed: `pip install pytest`
1. execute `pytest {directory_path}` in terminal to perform all tests in all testing files inside the specified directory
2. execute `pytest {file_path}` in terminal to perform all tests in the specified file
3. execute `pytest {file_path}::{TestClass}::{test_method}` in terminal to perform a specific test class/method inside the specified file
4. after `pip install pytest-xdist`, one may execute "pytest -n 4" to test in parallel with number of workers specified by `-n`
5. for more details, see https://docs.pytest.org/en/stable/usage.html
'''
import numpy as np
import pandas as pd

from numpy.testing import assert_array_equal
from pandas.testing import assert_frame_equal

import pytest

import pyleoclim as pyleo
from pyleoclim.utils.tsmodel import (
    ar1_sim,
    colored_noise,
)

# a collection of useful functions

def gen_normal(loc=0, scale=1, nt=100):
    ''' Generate random data with a Gaussian distribution
    '''
    t = np.arange(nt)
    v = np.random.normal(loc=loc, scale=scale, size=nt)
    return t, v

def gen_colored_noise(alpha=1, nt=100, f0=None, m=None, seed=None):
    ''' Generate colored noise
    '''
    t = np.arange(nt)
    v = colored_noise(alpha=alpha, t=t, f0=f0, m=m, seed=seed)
    return t, v


# Tests below
class TestUiScalogramSignifTest:
    ''' Tests for Scalogram.signif_test()
    '''
    
    @pytest.mark.parametrize('wave_method',['wwz','cwt'])
    def test_signif_test_t0(self, wave_method):
        ''' Test scalogram.signif_test() with default parameters
        '''
        alpha = 1
        t, v = gen_colored_noise(nt=100, alpha=alpha)
        ts = pyleo.Series(time=t, value=v)
        scal = ts.wavelet(method=wave_method)
        scal_signif = scal.signif_test(number=1)
    
    @pytest.mark.parametrize('ar1_method',['ar1asym', 'ar1sim'])
    def test_signif_test_t1(self,ar1_method):
        ''' Test scalogram.signif_test() with default parameters
        '''
        alpha = 1
        t, v = gen_colored_noise(nt=100, alpha=alpha)
        ts = pyleo.Series(time=t, value=v)
        scal = ts.wavelet(method='cwt')
        scal_signif = scal.signif_test(method=ar1_method,number=1)
